@@ -18,8 +18,8 @@
 #'   reproduction). Optionally with named rows and columns indicating the
 #'   corresponding life stage names.
 #' @param start The index (or stage name) of the first stage at which the author
-#'   considers the beginning of life. Defaults to \code{1}. Alternately, a numeric
-#'   vector giving the starting population vector (in which case
+#'   considers the beginning of life. Defaults to \code{1}. Alternately, a
+#'   numeric vector giving the starting population vector (in which case
 #'   \code{length(start)} must match \code{ncol(matU))}. See section
 #'   \emph{Starting from multiple stages}.
 #' @param xmax Maximum age to which the life table will be calculated (defaults
@@ -42,13 +42,16 @@
 #'   \item{x}{age at the start of the age interval \code{[x, x+1)}}
 #'   \item{Nx}{The number of individuals alive at age x. The initial number is
 #'   set with \code{radix}}
-#'   \item{Dx}{proportion of original cohort dying during the age interval \code{[x, x+1)}}
-#'   \item{lx}{survivorship, defined as the proportion of initial cohort surviving to the start of
-#'   age interval \code{[x, x+1)}}
-#'   \item{dx}{proportion of original cohort dying in the age interval \code{[x, x+1)}}
+#'   \item{Dx}{proportion of original cohort dying during the age interval
+#'   \code{[x, x+1)}}
+#'   \item{lx}{survivorship, defined as the proportion of initial cohort
+#'   surviving to the start of age interval \code{[x, x+1)}}
+#'   \item{dx}{proportion of original cohort dying in the age interval \code{[x,
+#'   x+1)}}
 #'   \item{ax}{The average time survived within the interval by those that die
 #'   during the age interval \code{[x, x+1)}. Assumed to be 0.5}
-#'   \item{hx}{force of mortality (hazard) during the age interval \code{[x, x+1)}}
+#'   \item{hx}{force of mortality (hazard) during the age interval \code{[x,
+#'   x+1)}}
 #'   \item{qx}{probability of death during the interval \code{[x, x+1)} for
 #'   those entering the interval}
 #'   \item{px}{probability of survival for the interval \code{[x, x+1)} for
@@ -106,10 +109,10 @@
 #'   may be a good idea to remove the final row of the table.
 #'
 #'   If \code{lx_crit} is sufficiently small that only a very small proportion
-#'   of the cohort reach this age (i.e., < 0.05), this should have minimal impact
-#'   on results. Nevertheless, for many analyses, the final row of the life
-#'   table should be treated with caution and perhaps removed from subsequent
-#'   analyses.
+#'   of the cohort reach this age (i.e., < 0.05), this should have minimal
+#'   impact on results. Nevertheless, for many analyses, the final row of the
+#'   life table should be treated with caution and perhaps removed from
+#'   subsequent analyses.
 #'
 #' @note Note that the units of time (e.g.. `x` and `ex`) in the returned life
 #'   table are the same as the projection interval (`ProjectionInterval`) of the
@@ -150,7 +153,9 @@
 #' data(mpm1)
 #'
 #' mpm_to_table(matU = mpm1$matU, start = 2, xmax = 15)
-#' mpm_to_table(matU = mpm1$matU, start = "small", xmax = 15) # equivalent using named life stages
+#'
+#' # equivalent using named life stages
+#' mpm_to_table(matU = mpm1$matU, start = "small", xmax = 15)
 #' mpm_to_table(matU = mpm1$matU, matF = mpm1$matF, start = 2, xmax = 15)
 #'
 #' ### starting from first reproduction
@@ -175,8 +180,12 @@ mpm_to_table <- function(matU, matF = NULL, matC = NULL, start = 1L,
   # Age-specific survivorship (lx)
   lx <- mpm_to_lx(matU, start, xmax, lx_crit)
   if (lx[length(lx)] > 0.05) {
-    warning(strwrap(prefix = " ", initial = "", "There are still a large proportion of the synthetic
-  cohort remaining alive in the final row of the life table. Consider changing values for `lx_crit` or `xmax`.\n"))
+    warning(strwrap(
+      prefix = " ", initial = "",
+      "There are still a large proportion of the synthetic
+  cohort remaining alive in the final row of the life table.
+    Consider changing values for `lx_crit` or `xmax`.\n"
+    ))
   }
   # Number left alive at age x
   Nx <- lx * radix
@@ -260,7 +269,7 @@ mpm_to_table <- function(matU, matF = NULL, matC = NULL, start = 1L,
     out$lxcx <- out$lx * out$cx
   }
 
-  if (!is.null(matF) & !is.null(matC)) {
+  if (!is.null(matF) && !is.null(matC)) {
     out$mxcx <- out$mx + out$cx
     out$lxmxcx <- out$lx * out$mxcx
   }
