@@ -14,8 +14,10 @@ checkValidMat <- function(M,
       call. = FALSE
     )
   }
-  if (fail_any_na && any(is.na(M))) {
-    stop("Argument ", mn, " contains missing values (i.e. <NA>).\n", call. = FALSE)
+  if (fail_any_na && anyNA(M)) {
+    stop("Argument ", mn, " contains missing values (i.e. <NA>).\n",
+      call. = FALSE
+    )
   }
   if (warn_all_zero && all(M == 0)) {
     warning("All elements of ", mn, " are zero.\n", call. = FALSE)
@@ -32,15 +34,18 @@ checkValidMat <- function(M,
 checkMatchingStageNames <- function(M, N = NULL) {
   if (is.null(N)) {
     if (!identical(rownames(M), colnames(M))) {
-      stop(strwrap(prefix = " ", initial = "", "When naming lifestages, both rows and columns
-                   must be named and their names must be identical.\n"))
+      stop(strwrap(prefix = " ", initial = "", "When naming lifestages, both
+      rows and columns must be named and their names must be identical.\n"))
     }
   } else {
-    if (!identical(rownames(M), colnames(M)) || !identical(rownames(N), colnames(N)) ||
+    if (!identical(rownames(M), colnames(M)) || !identical(
+      rownames(N),
+      colnames(N)
+    ) ||
       !identical(M * 0L, N * 0L)) {
-      stop(strwrap(prefix = " ", initial = "", "When naming lifestages, both rows and columns
-                   must be named their names must be identical, and they must be the same between
-                   both matrices passed to the function.\n"))
+      stop(strwrap(prefix = " ", initial = "", "When naming lifestages, both
+      rows and columns must be named their names must be identical, and they
+      must be the same between both matrices passed to the function.\n"))
     }
   }
 }
@@ -48,27 +53,33 @@ checkMatchingStageNames <- function(M, N = NULL) {
 #' @noRd
 checkValidStartLife <- function(s, M, start_vec = FALSE) {
   if (start_vec) {
-    # check that abundances of all stages have been set if passing a population vector
-    if ((length(s) > 1 & length(s) != ncol(M)) ||
+    # check that abundances of all stages have been set if passing
+    # a population vector
+    if ((length(s) > 1 && length(s) != ncol(M)) ||
       (is.numeric(s) && length(s) == 1 && !(s %in% seq_len(nrow(M)))) ||
-      (is.character(s) && length(s) == 1 && !(s %in% unique(unlist(dimnames(M)))))) {
-      stop(strwrap(prefix = " ", initial = "", "Argument 'start' must be an integer within 1:nrow(matU),
-                   a character matching a stage class name in dimnames(matU), or an integer vector of
-                   starting abundances of length ncol(matU).\n"),
+      (is.character(s) && length(s) == 1 &&
+        !(s %in% unique(unlist(dimnames(M)))))) {
+      stop(strwrap(prefix = " ", initial = "", "Argument 'start' must be an
+      integer within 1:nrow(matU), a character matching a stage class name in
+      dimnames(matU), or an integer vector of starting abundances of length
+      ncol(matU).\n"),
         call. = FALSE
       )
     }
   } else {
     # check that start is a single value, either an index or named life stage
-    if (length(s) != 1 || !(s %in% seq_len(nrow(M))) && !(s %in% unique(unlist(dimnames(M))))) {
-      stop(strwrap(prefix = " ", initial = "", "Argument 'start' must be an integer within 1:nrow(matU),
-                   or a character matching a stage class name in dimnames(matU).\n"),
+    if (length(s) != 1 || !(s %in% seq_len(nrow(M))) &&
+      !(s %in% unique(unlist(dimnames(M))))) {
+      stop(strwrap(prefix = " ", initial = "", "Argument 'start' must be an
+      integer within 1:nrow(matU), or a character matching a stage class name
+      in dimnames(matU).\n"),
         call. = FALSE
       )
     }
   }
 }
 
+#' @importFrom stats na.omit
 #' @noRd
 checkValidStages <- function(M, stages) {
   # checks that the stages vector supplied has valid indices or names
@@ -78,32 +89,39 @@ checkValidStages <- function(M, stages) {
       "the matrix (", ncol(M), ").\n",
       call. = FALSE
     )
-  } else if (is.numeric(stages) && !all(stages[!is.na(stages)] %in% 1:ncol(M))) {
+  } else if (is.numeric(stages) &&
+    !all(stages[!is.na(stages)] %in% seq_len(ncol(M)))) {
     stop("Some stage indices ",
       ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
       "exceeded matrix dimension (", nrow(M), "): ",
       paste(stages[stages > ncol(M) | stages <= 0L], collapse = ", "),
       call. = FALSE
     )
-  } else if (is.character(stages) && any(!stages[!is.na(stages)] %in% colnames(M))) {
+  } else if (is.character(stages) &&
+    !all(stages[!is.na(stages)] %in% colnames(M))) {
     stop("Some stage names ",
       ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
       "were not found in matrix: ",
       paste(stages[!stages %in% colnames(M)], collapse = ", "),
       call. = FALSE
     )
-  } else if (is.list(stages) && any(sapply(stages, is.numeric)) &&
-    any(!unique(unlist(stages))[!is.na(unique(unlist(stages)))] %in% 1:ncol(M))) {
+  } else if (is.list(stages) && any(vapply(stages, is.numeric, logical(1))) &&
+    !all(na.omit(unique(unlist(stages))) %in%
+      seq_len(ncol(M)))) {
     stop("Some stage indices ",
       ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
       "exceeded matrix dimension (", nrow(M), "): ",
-      paste(unique(unlist(stages))[!unique(unlist(stages)) %in% 1:ncol(M)],
+      paste(
+        unique(unlist(stages))[!unique(unlist(stages)) %in%
+          seq_len(ncol(M))],
         collapse = ", "
       ),
       call. = FALSE
     )
-  } else if (is.list(stages) && any(sapply(stages, is.character)) &&
-    any(!unique(unlist(stages))[!is.na(unique(unlist(stages)))] %in% colnames(M))) {
+  } else if (is.list(stages) && any(vapply(stages, is.character, logical(1))) &&
+    !all(na.omit(unique(unlist(stages))) %in%
+      colnames(M))
+  ) {
     stop("Some stage names ",
       ifelse(is.null(arg), "", paste0("in `", arg, "` ")),
       "were not found in matrix: ",
@@ -117,8 +135,8 @@ checkValidStages <- function(M, stages) {
 
 #' @noRd
 colSums2 <- function(mat) {
-  # like colSums(x, na.rm = TRUE), except that column with only NAs will return NA
-  #  rather than 0
+  # like colSums(x, na.rm = TRUE), except that column with only NAs will return
+  # NA rather than 0
   apply(mat, 2, function(x) {
     ifelse(all(is.na(x)), NA_real_, sum(x, na.rm = TRUE))
   })
@@ -130,7 +148,7 @@ colSums2 <- function(mat) {
 meanMat <- function(x, na.rm = FALSE) {
   n_row <- vapply(x, nrow, numeric(1))
   n_col <- vapply(x, ncol, numeric(1))
-  if (length(unique(n_row)) != 1 | length(unique(n_col)) != 1) {
+  if (length(unique(n_row)) != 1 || length(unique(n_col)) != 1) {
     stop("All matrices in list must be of same dimension.\n")
   }
   if (na.rm) x <- lapply(x, zero_NA)
@@ -159,8 +177,8 @@ area_under_curve <- function(x, y) {
 #' @importFrom MASS ginv
 .matrix_inverse <- function(mat) {
   mat_inv <- try(solve(mat), silent = TRUE)
-  if ("try-error" %in% class(mat_inv)) {
-    mat_inv <- MASS::ginv(mat)
+  if (inherits(mat_inv, "try-error")) {
+    mat_inv <- ginv(mat)
   }
   return(mat_inv)
 }
