@@ -9,13 +9,13 @@ test_that("mpm_to_ functions work correctly", {
   expect_true(all(lx == cummin(lx))) # monotonic declining
 
   lx_zero <- suppressWarnings(mpm_to_lx(mat_u_zero, start = 1, xmax = xmax))
-  expect_equal(lx_zero[1], 1)
+  expect_identical(lx_zero[1], 1)
   expect_true(all(lx_zero[-1] == 0))
 
   # specify start as integer vs. vector
   lx_a <- mpm_to_lx(mat_u, start = 2)
   lx_b <- mpm_to_lx(mat_u, start = c(0, 1, 0, 0))
-  expect_equal(lx_a, lx_b)
+  expect_identical(lx_a, lx_b)
 
   # mpm_to_px
   px <- mpm_to_px(mat_u, start = 1, xmax = xmax, lx_crit = 0)
@@ -39,11 +39,14 @@ test_that("mpm_to_ functions work correctly", {
   lx_named <- mpm_to_lx(mat_u_named, start = "sm", xmax = xmax, lx_crit = 0)
   px_named <- mpm_to_px(mat_u_named, start = 1, xmax = xmax, lx_crit = 0)
   hx_named <- mpm_to_hx(mat_u_named, start = 1, xmax = xmax, lx_crit = 0)
-  mx_named <- mpm_to_mx(mat_u_named, mat_f_named, start = 1, xmax = xmax, lx_crit = 0)
-  expect_equal(lx, lx_named)
-  expect_equal(px, px_named)
-  expect_equal(hx, hx_named)
-  expect_equal(mx, mx_named)
+  mx_named <- mpm_to_mx(mat_u_named, mat_f_named,
+    start = 1, xmax = xmax,
+    lx_crit = 0
+  )
+  expect_identical(lx, lx_named)
+  expect_identical(px, px_named)
+  expect_identical(hx, hx_named)
+  expect_identical(mx, mx_named)
 })
 
 
